# jmcm

## Description
jmcm is an open-source Python package for fitting the joint mean-covariance models for longitudinal data. 

It provides:
* function to estimate parameters for the mean, innovation variance, and generalised auto-regressive coefficient
* function to do the Wald hypothesis tests to check the significance of the parameters
* model selection procedures
* bootstrap method to plot the curves for the mean, innovation variance, and generalised auto-regressive coefficient

## Source code
https://github.com/Xuerui-Yang/jmcm

## Installation
```
pip install jmcm
```
